==> ktorrent-20.11.80.tar.xz: ktorrent-20.11.80/ktorrent/view/viewselectionmodel.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include <util/log.h>
#include "viewselectionmodel.h"
#include "viewmodel.h"

using namespace bt;

namespace kt
{

ViewSelectionModel::ViewSelectionModel(ViewModel* vm, QObject* parent) : ItemSelectionModel(vm, parent)
{
}


ViewSelectionModel::~ViewSelectionModel()
{
}
}

==> ktorrent-21.04.0.tar.xz: ktorrent-21.04.0/ktorrent/view/viewselectionmodel.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include "viewselectionmodel.h"
#include "viewmodel.h"
#include <util/log.h>

using namespace bt;

namespace kt
{
ViewSelectionModel::ViewSelectionModel(ViewModel *vm, QObject *parent)
    : ItemSelectionModel(vm, parent)
{
}

ViewSelectionModel::~ViewSelectionModel()
{
}
}
